AddConnectionModbusRTU class

Inheritance

Constructors

AddConnectionModbusRTU({required ParametersModbusRTU parameters, List<ConnectionTag> tags = const []})
Returns a new AddConnectionModbusRTU instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
parameters ↔ ParametersModbusRTU
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<ConnectionTag>
getter/setter pair
type ↔ ProtocolEnum
finalgetter/setter pairinherited-setteroverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → AddConnectionModbusRTU?
Returns a new AddConnectionModbusRTU instance and imports its values from value if it's a Map, null otherwise.
override
listFromJson(dynamic json, {bool growable = false}) → List<AddConnectionModbusRTU>?
mapFromJson(dynamic json) → Map<String, AddConnectionModbusRTU>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<AddConnectionModbusRTU>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.