AddConnectionOPCUA class

Inheritance

Constructors

AddConnectionOPCUA({required ParametersOPCUA parameters, List<ConnectionTag> tags = const []})
Returns a new AddConnectionOPCUA instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
parameters ↔ ParametersOPCUA
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<ConnectionTag>
getter/setter pair
type ↔ ProtocolEnum
finalgetter/setter pairinherited-setteroverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → AddConnectionOPCUA?
Returns a new AddConnectionOPCUA instance and imports its values from value if it's a Map, null otherwise.
override
listFromJson(dynamic json, {bool growable = false}) → List<AddConnectionOPCUA>?
mapFromJson(dynamic json) → Map<String, AddConnectionOPCUA>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<AddConnectionOPCUA>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.