Connection class

Implementers

Constructors

Connection({String? id, required ProtocolEnum type, List<ConnectionTag>? tags = const []})
Returns a new Connection instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<ConnectionTag>?
getter/setter pair
type ↔ ProtocolEnum
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Connection?
Returns a new Connection instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<Connection>?
mapFromJson(dynamic json) → Map<String, Connection>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<Connection>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.