ConnectionS7 class

Inheritance

Constructors

ConnectionS7({String? id, required ParametersS7 parameters, List<ConnectionTag>? tags})
Returns a new ConnectionS7 instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
getter/setter pairoverride
parameters ↔ ParametersS7
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<ConnectionTag>?
getter/setter pairinherited
type ↔ ProtocolEnum
finalgetter/setter pairinherited-setteroverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → ConnectionS7?
Returns a new ConnectionS7 instance and imports its values from value if it's a Map, null otherwise.
override
listFromJson(dynamic json, {bool growable = false}) → List<ConnectionS7>?
override
mapFromJson(dynamic json) → Map<String, ConnectionS7>
override
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<ConnectionS7>>
override

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.