decode method
Decodes a data to a Discover200ResponseInnerIdentifierTypeEnum.
If allowNull is true and the data cannot be decoded successfully,
then null is returned. However, if allowNull is false and the data
cannot be decoded successfully, then an UnimplementedError is thrown.
The allowNull is very handy when an API changes and a new enum value is added or removed,
and users are still using an old app with the old code.
Implementation
Discover200ResponseInnerIdentifierTypeEnum? decode(dynamic data,
{bool allowNull = true}) {
if (data != null) {
switch (data.toString()) {
case r's':
return Discover200ResponseInnerIdentifierTypeEnum.s;
case r'i':
return Discover200ResponseInnerIdentifierTypeEnum.i;
case r'g':
return Discover200ResponseInnerIdentifierTypeEnum.g;
case r'b':
return Discover200ResponseInnerIdentifierTypeEnum.b;
default:
if (!allowNull) {
throw ArgumentError('Unknown enum value to decode: $data');
}
}
}
return null;
}