Error class

Constructors

Error({required ErrorTypeEnum type, required num code, required String message})
Returns a new Error instance.

Properties

code ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
message ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ErrorTypeEnum
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Error?
Returns a new Error instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<Error>?
mapFromJson(dynamic json) → Map<String, Error>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<Error>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.