fromJson static method

NodeOPCUA? fromJson(
  1. dynamic value
)

Returns a new NodeOPCUA instance and imports its values from value if it's a Map, null otherwise.

Implementation

// ignore: prefer_constructors_over_static_methods
static NodeOPCUA? fromJson(dynamic value) {
  if (value is Map) {
    final json = value.cast<String, dynamic>();

    // Ensure that the map contains the required keys.
    // Note 1: the values aren't checked for validity beyond being non-null.
    // Note 2: this code is stripped in release mode!
    assert(() {
      requiredKeys.forEach((key) {
        assert(json.containsKey(key),
            'Required key "NodeOPCUA[$key]" is missing from JSON.');
        assert(json[key] != null,
            'Required key "NodeOPCUA[$key]" has a null value in JSON.');
      });
      return true;
    }());

    // IMPORTANT: Since anyOf code generator is not working, will check the type this way
    assert(json[r'identifier'] is int || json[r'identifier'] is String);
    return NodeOPCUA(
      namespaceIndex: mapValueOfType<int>(json, r'namespaceIndex')!,
      identifierType:
          NodeOPCUAIdentifierTypeEnum.fromJson(json[r'identifierType'])!,
      identifier: json[r'identifier']!,
    );
  }
  return null;
}