ParametersS7 class

Constructors

ParametersS7({required int rack, required int slot, required num port, required String host})
Returns a new ParametersS7 instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
host ↔ String
getter/setter pair
port ↔ num
Minimum value: 0 Maximum value: 65535
getter/setter pair
rack ↔ int
Minimum value: 0
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slot ↔ int
Minimum value: 0
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → ParametersS7?
Returns a new ParametersS7 instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<ParametersS7>?
mapFromJson(dynamic json) → Map<String, ParametersS7>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<ParametersS7>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.