ReadS7 class

Inheritance

Constructors

ReadS7({required ParametersS7 connection, List<MetricS7> metrics = const []})
Returns a new ReadS7 instance.

Properties

connection ↔ ParametersS7
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
metrics ↔ List<MetricS7>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ProtocolEnum
finalgetter/setter pairinherited-setteroverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → ReadS7?
Returns a new ReadS7 instance and imports its values from value if it's a Map, null otherwise.
override
listFromJson(dynamic json, {bool growable = false}) → List<ReadS7>?
mapFromJson(dynamic json) → Map<String, ReadS7>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<ReadS7>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.