WriteModbusRTU class

Inheritance

Constructors

WriteModbusRTU({required ParametersModbusRTU connection, List<WriteModbusRTUMetrics> metrics = const []})
Returns a new WriteModbusRTU instance.

Properties

connection ↔ ParametersModbusRTU
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
metrics ↔ List<WriteModbusRTUMetrics>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ProtocolEnum
finalgetter/setter pairinherited-setteroverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → WriteModbusRTU?
Returns a new WriteModbusRTU instance and imports its values from value if it's a Map, null otherwise.
override
listFromJson(dynamic json, {bool growable = false}) → List<WriteModbusRTU>?
mapFromJson(dynamic json) → Map<String, WriteModbusRTU>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<WriteModbusRTU>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.