DiscoverOPCUA class
- Inheritance
-
- Object
- DiscoverRequest
- DiscoverOPCUA
Constructors
- DiscoverOPCUA({required ParametersOPCUA connection, NodeOPCUA? node})
- Returns a new DiscoverOPCUA instance.
Properties
- connection ↔ ParametersOPCUA
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- node ↔ NodeOPCUA?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ ProtocolEnum
-
finalgetter/setter pairinherited-setteroverride-getter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → DiscoverOPCUA? -
Returns a new DiscoverOPCUA instance and imports its values from
valueif it's a Map, null otherwise.override -
listFromJson(
dynamic json, {bool growable = false}) → List< DiscoverOPCUA> ? -
mapFromJson(
dynamic json) → Map< String, DiscoverOPCUA> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< DiscoverOPCUA> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.